package view;

import controller.SpaceInvaderGame;

import javax.swing.*;
import java.awt.*;

// The panel in which the game is rendered.
@SuppressWarnings("serial")
public class GamePanel extends JPanel {

  private static final String OVER = "Game Over!";
  private static final String REPLAY = "R to replay";
  private SpaceInvaderGame game;

  // Constructs a game panel
  // sets size and background colour of panel,
  // updates this with the game to be displayed
  public GamePanel(SpaceInvaderGame g) {
    setPreferredSize(new Dimension(SpaceInvaderGame.WIDTH, SpaceInvaderGame.HEIGHT));
    setBackground(Color.GRAY);
    this.game = g;
  }

  @Override
  protected void paintComponent(Graphics g) {
    super.paintComponent(g);

    drawGame(g);

    if (game.isOver()) {
      gameOver(g);
    }
  }

  // the game is drawn onto the Graphics object g
  private void drawGame(Graphics g) {
    game.draw(g);
  }

  // Draws the "game over" message and replay instructions
  private void gameOver(Graphics g) {
    Color saved = g.getColor();
    g.setColor(new Color(0, 0, 0));
    g.setFont(new Font("Arial", 20, 20));
    FontMetrics fm = g.getFontMetrics();
    centreString(OVER, g, fm, SpaceInvaderGame.HEIGHT / 2);
    centreString(REPLAY, g, fm, SpaceInvaderGame.HEIGHT / 2 + 50);
    g.setColor(saved);
  }

  // Centres the string str horizontally onto g at vertical position yPos
  private void centreString(String str, Graphics g, FontMetrics fm, int yPos) {
    int width = fm.stringWidth(str);
    g.drawString(str, (SpaceInvaderGame.WIDTH - width) / 2, yPos);
  }
}
